## GAPLEN

El Grupo de Aprendizaje de Procesamiento del Lenguaje Natural (GAPLEN) es un conjunto de personas que quieren aprender juntas PLN, con el objetivo inicial de estudiar el [libro oficial de NLTK](http://www.nltk.org/book/).

La *documentación* generada por GAPLEN y contenida en este repositorio puede visitarse en [este enlace](http://gaplen.readthedocs.io/es/latest/).

Si quieres participar, escríbenos a lingwars arroba gmail punto com y te pasamos el enlace al grupo de Slack para que te unas.